==> gbsite-1.1.0.tar.gz: gbsite/htdocs/docview.php <==
<?

/**************************************************
Program name:		doc.php  
Author:			Allen McGrath (allen@greatbridge.com)

Description:		
Create Date:		11/28/00 

Modified Date(s):	12/06/2000
			Chris Ryan <chris@greatbridge.com>
			added in code to handle the html versions of the docs
**************************************************/
 $web_page = "docpage";
include("site_info.php");
$group_group_id = "documents";

$HTML_DOC_PATH = "/usr/local/gbsite/gbpgdocs";
if($fformat == "") {
    $url_parts = explode("/",$PATH_INFO);
    array_shift($url_parts);
    $doc = array_shift($url_parts);
    if(empty($doc)) {
        $web_page = "documententrypage";
        include($page_template);
        exit();
    }
    $fformat = "HTML";
    $file = implode("/",$url_parts);
    if(is_dir("$HTML_DOC_PATH/$doc/$file")) {
        $file .= $doc . "TOC.html";
    }
    $INCLUDE_ADDITIONAL_CSS = "$HTML_DOC_PATH/$doc/standard.css";
}

if (empty($doc)) {
  $context = "There was a problem with your request.  Specifically:";
  $context_error[] = "No document was identified.";
  $web_page="contextpage";
  include($page_template);
  return;
} elseif (empty($mktg_contact) && ($doc == "UG" || $doc == "RG")) {
  $context = "User Survey";
  $context_error[] = "Please take a moment to provide us with some information and your comments below. Rest assured that we won't share your information with anyone else.";
  $web_page="mktginfopage";
  include($page_template);
  return; 

}

# all should be good at this point.
# figure out the document they want, and the format.
if ($fformat == "PDF") {

  switch ($doc) {
    case "RG":
      $redir = "/documents/pdf/GBpgSQL703_referenceGuide.pdf";
      $doc_name = "Great Bridge PostgreSQL Reference Guide";
    break;

    case "UG":
      $redir = "/documents/pdf/GBpgSQL703_usersGuide.pdf";  
      $doc_name = "Great Bridge PostgreSQL Users Guide";
    break;

    case "IG" :
      $redir = "/documents/pdf/GBpgSQL703_installGuide.pdf";  
      $doc_name = "Great Bridge PostgreSQL Installation Guide";
    break;
  }
  Redirectto($redir);
  $web_page = "contextpage";
  $context = "Thank you for downloading the ". $doc_name . ".  Please contact us at 
  <a href=mailto:docs@greatbridge.com>docs@greatbridge.com</a>
  with any comments about the documentation.";
}



  include($page_template);
?>

==> gbsite-1.1.1.tar.gz: gbsite/htdocs/docview.php <==
<?

/**************************************************
Program name:		doc.php  
Author:			Allen McGrath (allen@greatbridge.com)

Description:		
Create Date:		11/28/00 

Modified Date(s):	12/06/2000
			Chris Ryan <chris@greatbridge.com>
			added in code to handle the html versions of the docs
**************************************************/
 $web_page = "docpage";
include("site_info.php");
$group_group_id = "documents";

$HTML_DOC_PATH = "/usr/local/gbsite/gbpgdocs";
if($fformat == "") {
    $url_parts = explode("/",$PATH_INFO);
    array_shift($url_parts);
    $doc = array_shift($url_parts);
    if(empty($doc)) {
        $web_page = "documententrypage";
        include($page_template);
        exit();
    }
    $fformat = "HTML";
    $file = implode("/",$url_parts);
    if(is_dir("$HTML_DOC_PATH/$doc/$file")) {
        $file .= $doc . "TOC.html";
    }
    $INCLUDE_ADDITIONAL_CSS = "$HTML_DOC_PATH/$doc/standard.css";
}

if (empty($doc)) {
  $context = "There was a problem with your request.  Specifically:";
  $context_error[] = "No document was identified.";
  $web_page="contextpage";
  include($page_template);
  return;
} elseif (empty($mktg_contact) && ($doc == "UG" || $doc == "RG")) {
  $context = "User Survey";
  $context_error[] = "Please take a moment to provide us with some information and your comments below. Rest assured that we won't share your information with anyone else.";
  $web_page="mktginfopage";
  include($page_template);
  return; 

}

# all should be good at this point.
# figure out the document they want, and the format.
if ($fformat == "PDF") {

  switch ($doc) {
    case "RG":
      $redir = "/documents/pdf/gb_ref_200010.pdf";
      $doc_name = "Great Bridge PostgreSQL Reference Guide";
    break;

    case "UG":
      $redir = "/documents/pdf/gb_users_200010.pdf";  
      $doc_name = "Great Bridge PostgreSQL Users Guide";
    break;

    case "IG" :
      $redir = "/documents/pdf/gb_install_200010.pdf";  
      $doc_name = "Great Bridge PostgreSQL Installation Guide";
    break;
  }
  Redirectto($redir);
  $web_page = "contextpage";
  $context = "Thank you for downloading the ". $doc_name . ".  Please contact us at 
  <a href=mailto:docs@greatbridge.com>docs@greatbridge.com</a>
  with any comments about the documentation.";
}



  include($page_template);
?>
